<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_Cookie_Banner
 * @subpackage Gdpr_Cookie_Banner/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Gdpr_Cookie_Banner
 * @subpackage Gdpr_Cookie_Banner/includes
 * @author     Your Name <email@example.com>
 */
class Gdpr_Cookie_Banner {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Gdpr_Cookie_Banner_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $gdpr_cookie_banner    The string used to uniquely identify this plugin.
	 */
	protected $gdpr_cookie_banner;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */


	static $basename = null;


	public function __construct() {
		
		if ( defined( 'GDPR_COOKIE_BANNER_VERSION' ) ) {
			$this->version = GDPR_COOKIE_BANNER_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->gdpr_cookie_banner = 'gdpr-cookie-banner';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Gdpr_Cookie_Banner_Loader. Orchestrates the hooks of the plugin.
	 * - Gdpr_Cookie_Banner_i18n. Defines internationalization functionality.
	 * - Gdpr_Cookie_Banner_Admin. Defines all hooks for the admin area.
	 * - Gdpr_Cookie_Banner_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-cookie-banner-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-cookie-banner-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-gdpr-cookie-banner-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-gdpr-cookie-banner-public.php';

		$this->loader = new Gdpr_Cookie_Banner_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Gdpr_Cookie_Banner_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Gdpr_Cookie_Banner_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Gdpr_Cookie_Banner_Admin( $this->get_gdpr_cookie_banner(), $this->get_version() );

		/*
			The Following action adds the plugin option to the Admin 
			menu under Settings
		*/

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'pp_add_admin_menu', 11 );
		
		/*
			The Following action is executed after loads its core, 
			after registering all actions, finds out what page to 
			execute and before producing the actual output(before 
			calling any action callback)
		*/
		$this->loader->add_action( 'admin_init', $plugin_admin, 'pp_admin_display_options'); 

		/*
			Code to enqueue admin styles for the plugin
		*/
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );

		/*
			Code to enqueue admin scripts for the plugin
		*/
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		/*
			Code to code to add plugin's Settings link on the admin screen
		*/
		$this->loader->add_filter( 'plugin_action_links_' . self::$basename, $plugin_admin, 'pp_gdpr_cookie_banner_settings_link', 15 );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Gdpr_Cookie_Banner_Public( $this->get_gdpr_cookie_banner(), $this->get_version() );

		$pp_banner_position = get_option( 'pp_banner_position' );

		if( 'top' === $pp_banner_position ) {

			$action = 'wp_head';

		} else {

			$action = 'wp_footer';
		}

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$this->loader->add_action( $action, $plugin_public, 'display_banner', 15 );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_gdpr_cookie_banner() {
		return $this->gdpr_cookie_banner;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Gdpr_Cookie_Banner_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
